aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMichal Jagiello <michal.jagiello@t-mobile.pl>2021-03-19 20:49:16 +0000
committerMichal Jagiello <michal.jagiello@t-mobile.pl>2021-03-19 20:49:16 +0000
commit612848c7353ced7aa0f16ff90ad3afffa65e8aed (patch)
tree0beccf962c5231a89ff3e5f667b04700174ca7a4
parent2939e020dd9a7a34dd14b6b3c776f4d1e55d1328 (diff)
Wait 15 minutes for orchestration requests
Issue-ID: TEST-316 Signed-off-by: Michal Jagiello <michal.jagiello@t-mobile.pl> Change-Id: Iae4398b36293e78cd8e9a98782ed26eeba4d7d1e
-rw-r--r--src/onaptests/configuration/settings.py2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/onaptests/configuration/settings.py b/src/onaptests/configuration/settings.py
index 5cea0a6..491e5e0 100644
--- a/src/onaptests/configuration/settings.py
+++ b/src/onaptests/configuration/settings.py
@@ -46,4 +46,4 @@ K8S_CONFIG = None # None means it will use default config (~/.kube/config)
K8S_NAMESPACE = "onap" # Kubernetes namespace
#SOCK_HTTP = "socks5h://127.0.0.1:8091"
-ORCHESTRATION_REQUEST_TIMEOUT = 60.0 * 10 # Ten minutes in seconds
+ORCHESTRATION_REQUEST_TIMEOUT = 60.0 * 15 # 15 minutes in seconds